/*
 * Copyright 2014 Kai Uwe Broulik <kde@privat.broulik.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.kde.akademy.android;

import android.app.Activity;

import android.app.AlertDialog;
import android.app.AlertDialog.Builder;
import android.content.DialogInterface;

// Fully qualified class name will be package+name, ie org/kde/akademy/android/AndroidMessageBox
public class AndroidMessageBox
{

    // To avoid using Qt non-public Java API, we use QtAndroid::activity() and pass it along
    // you could get it directly from QtNative.activity()
    final private Activity m_qtActivity;

    // The "pointer" to our class instance
    final private long m_handler;

    public AndroidMessageBox(final Activity qtActivity, final long handler)
    {
        m_qtActivity = qtActivity;
        m_handler = handler;
    }

    public void show(final String title, final String text, final String rejectButton, final String acceptButton)
    {
        // Basically anything that does something on a screen needs to use runOnUiThread
        m_qtActivity.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                // Create an Alert Dialog
                AlertDialog.Builder dialog = new AlertDialog.Builder(m_qtActivity);

                // I think setTitle(null) will blow up
                if (title != null) {
                    dialog.setTitle(title);
                }

                dialog.setMessage(text);

                if (acceptButton != null) {
                    dialog.setPositiveButton(acceptButton, new DialogInterface.OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialog, int which) {
                            // Call the native method and give it the "handler"
                            accepted(m_handler);
                        }
                    });
                }

                if (rejectButton != null) {
                    dialog.setNegativeButton(rejectButton, new DialogInterface.OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialog, int which) {
                            rejected(m_handler);
                        }
                    });
                }

                // Show the dialog
                dialog.show();
            }
        });
    }

    // These are the native methods we registered in the .cpp part
    public static native void accepted(long handler);
    public static native void rejected(long handler);

}
