/*
 * Copyright 2014 Kai Uwe Broulik <kde@privat.broulik.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ANDROIDSHAREPROVIDER_H
#define ANDROIDSHAREPROVIDER_H

#include <QObject>
#include <QScopedPointer>

class QString;
class AndroidShareResultReceiver; // This thing will handle the "return value" of the share dialog

class AndroidShareProvider : public QObject
{
    Q_OBJECT

public:
    explicit AndroidShareProvider(QObject *parent = nullptr);
    ~AndroidShareProvider();

public slots:
    // Android allows to specify the title of the dialog (prompt)
    void share(const QString &prompt, const QString &title, const QString &text);

signals:
    // The "type" is the handler that executed the task, such as "com.company.someApp"
    void shared(const QString &type);
    void error(const QString &type);

private:
    QScopedPointer<AndroidShareResultReceiver> m_receiver;

};

#endif // ANDROIDSHAREPROVIDER_H
