/*
 * Copyright 2014 Kai Uwe Broulik <kde@privat.broulik.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import QtQuick 2.2
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1

import org.kde.akademy.android 1.0

ApplicationWindow {
    visible: true
    title: "Hello, Akademy"

    ShareProvider {
        id: shareProvider
        onShared: {
            messageBox.title = "Thank you!"
            if (type) {
                messageBox.text = "You shared this stuff to the world via " + type + "!"
            } else {
                messageBox.text = "You shared this stuff to the world!"
            }
            messageBox.show()
        }
        onError: {
            messageBox.title = "Sorry :("
            if (type) {
                messageBox.text = "Sharing via " + type + " failed unfortunately."
            } else {
                messageBox.text = "You cancelled this, didn't you?!"
            }
            messageBox.show()
        }
    }

    MessageBox {
        id: messageBox
        acceptButton: "Do something else"
        rejectButton: "I quit!"

        onRejected: Qt.quit()
        onAccepted: console.log("User wants to do something else")
    }

    ColumnLayout {
        anchors.centerIn: parent
        Label {
            horizontalAlignment: Text.AlignHCenter
            text: "Tell your friends all about this"
            font.bold: true
        }

        TextField {
            id: textfield
            Layout.fillWidth: true
        }

        TextArea {
            id: textarea
            Layout.fillWidth: true
        }

        Button {
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Share it!"
            onClicked: shareProvider.share("Share stuff with whom?", textfield.text, textarea.text)
        }
    }

}
