/*
 * Copyright 2014 Kai Uwe Broulik <kde@privat.broulik.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef IOSMESSAGEBOX_H
#define IOSMESSAGEBOX_H

#include <QObject>
#include <QString>

// You cannot include objective C headers in a C++ header, so we forward declare it
Q_FORWARD_DECLARE_OBJC_CLASS(NSObject);

class IosMessageBox : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString title MEMBER m_title)
    Q_PROPERTY(QString text MEMBER m_text)

    Q_PROPERTY(QString rejectButton MEMBER m_rejectButton)
    Q_PROPERTY(QString acceptButton MEMBER m_acceptButton)

public:
    explicit IosMessageBox(QObject *parent = 0);
    ~IosMessageBox();

    Q_INVOKABLE void show();

signals:
    void accepted();
    void rejected();

private:
    QString m_title;
    QString m_text;

    QString m_rejectButton;
    QString m_acceptButton;

    // Our delegate doing event handling
    NSObject *m_delegate;

};

#endif // IOSMESSAGEBOX_H
