/*
 * Copyright 2014 Kai Uwe Broulik <kde@privat.broulik.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "iosmessagebox.h"

#include <UIKit/UIKit.h>

// The definition of our delegate
@interface IosMessageBoxDelegate : NSObject {
    // Just a pointer to our instance so we can emit signals
    IosMessageBox *m_messageBox;
}
@end

@implementation IosMessageBoxDelegate

// The "constructor", it inits the NSObject super class and then returns
- (id) initWithIosMessageBox:(IosMessageBox *)messageBox
{
    self = [super init];
    if (self) {
        m_messageBox = messageBox;
    }
    return self;
}

// This is called by the UIAlertView when a button is pressed
- (void) alertView:(UIAlertView*)alertView clickedButtonAtIndex:(NSInteger)buttonIndex {
    // Since we only have one AlertView with its own delegate, we don't care about which one it is
    Q_UNUSED(alertView);
    // Emit stuff
    if (buttonIndex == 0) {
        m_messageBox->rejected();
    } else if (buttonIndex == 1) {
        m_messageBox->accepted();
    }
}

@end

IosMessageBox::IosMessageBox(QObject *parent)
    : QObject(parent)
    , m_rejectButton(QStringLiteral("Close")) // Don't do this ;)
    // "initWithFoo" is the Objective C way of naming things
    // and it also distinguishes between allocation and initialization
    , m_delegate([[IosMessageBoxDelegate alloc] initWithIosMessageBox:this])
{

}

IosMessageBox::~IosMessageBox()
{
    [m_delegate release];
}

void IosMessageBox::show()
{
    if (m_title.isEmpty() || m_text.isEmpty()) {
        return;
    }

    // Alloc the alert view and init it with all these parameters
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:m_title.toNSString()
                                                    message:m_text.toNSString()
                                                   delegate:m_delegate
                                          cancelButtonTitle:m_rejectButton.toNSString()
                                          otherButtonTitles:nil]; // We don't always have a secondary button, adding it later

    if (!m_acceptButton.isEmpty()) {
        [alert addButtonWithTitle:m_acceptButton.toNSString()];
    }

    // Show is blocking
    [alert show];
    // Release right afterwards
    [alert release];
    // You might as well also instantiate your delegate and release it the same way as the AlertView
}
